==> PSyclone-1.9.0.tar.gz: PSyclone-1.9.0/examples/psyir/README.md <==
<!--
BSD 3-Clause License

Copyright (c) 2019, Science and Technology Facilities Council.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

Author R. W. Ford, STFC Daresbury Lab
-->

# PSyclone PSyIR Examples

This directory contains examples of how to create and/or modify
instances of PSyIR and how to use backends to transform them into
code.

## Example 1:

Create an instance of PSyIR using many of the generic PSyIR nodes and
output the resultant tree as Fortran and C. Currently the C
backend does not support all of the node types so it only outputs a
subset of the tree. First, ensure that PSyclone is installed,
then run:

```sh
> python create.py
```

==> PSyclone-2.2.0.tar.gz: PSyclone-2.2.0/examples/psyir/README.md <==
<!--
BSD 3-Clause License

Copyright (c) 2019-2021, Science and Technology Facilities Council.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

Authors: R. W. Ford, A. R. Porter and S. Siso STFC Daresbury Lab
-->

# PSyclone PSyIR Examples

This directory contains examples of how to create and/or modify
instances of PSyIR and how to use backends to transform them into
code.

All of these examples require PSyclone to be installed.

## Example 1:

Create an instance of PSyIR using many of the generic PSyIR nodes and
output the resultant tree as Fortran and C. Currently the C
backend does not support all of the node types so it only outputs a
subset of the tree. This example may be run by doing:

```sh
> python create.py
```

## Example 2:

Demonstrates how to create and manipulate structure types (a.k.a.
derived types in Fortran) within the PSyIR.
To run this example:

```sh
> python create_structure_types.py
```

## Example 3:

Demonstrates how to manipulate an existing PSyIR tree. This example
imports the PSyIR created in Example 1, applies some modifications
to it and then outputs the modified PSyIR as Fortran code. This example may
be run by doing:

```sh
> python modify.py
```
